diff lisp/calendar/calendar.el @ 2326:cac023fe9d13

* diary-insert.el: Change the name to diary-ins.el. * calendar.el: Change all autoload references to diary-ins.
author Jim Blandy <jimb@redhat.com>
date Tue, 23 Mar 1993 02:16:18 +0000
parents 2c7997f249eb
children e1b71e3a2742
line wrap: on
line diff
--- a/lisp/calendar/calendar.el	Tue Mar 23 00:54:49 1993 +0000
+++ b/lisp/calendar/calendar.el	Tue Mar 23 02:16:18 1993 +0000
@@ -53,7 +53,7 @@
 
 ;; The following files are part of the calendar/diary code:
 
 ;;       diary.el, diary-insert.el     Diary functions
 ;;       holidays.el                   Holiday functions
 ;;       cal-french.el                 French Revolutionary calendar
 ;;       cal-mayan.el                  Mayan calendars
@@ -1241,60 +1241,60 @@
 Each entry in diary-file visible in the calendar window is marked."
   t)
 
-(autoload 'insert-diary-entry "diary-insert"
+(autoload 'insert-diary-entry "diary-ins"
   "Insert a diary entry for the date indicated by point."
   t)
 
-(autoload 'insert-weekly-diary-entry "diary-insert"
+(autoload 'insert-weekly-diary-entry "diary-ins"
   "Insert a weekly diary entry for the day of the week indicated by point."
   t)
 
-(autoload 'insert-monthly-diary-entry "diary-insert"
+(autoload 'insert-monthly-diary-entry "diary-ins"
   "Insert a monthly diary entry for the day of the month indicated by point."
   t)
 
-(autoload 'insert-yearly-diary-entry "diary-insert"
+(autoload 'insert-yearly-diary-entry "diary-ins"
   "Insert an annual diary entry for the day of the year indicated by point."
   t)
 
-(autoload 'insert-anniversary-diary-entry "diary-insert"
+(autoload 'insert-anniversary-diary-entry "diary-ins"
   "Insert an anniversary diary entry for the date indicated by point."
   t)
 
-(autoload 'insert-block-diary-entry "diary-insert"
+(autoload 'insert-block-diary-entry "diary-ins"
   "Insert a block diary entry for the dates indicated by point and mark."
   t)
 
-(autoload 'insert-cyclic-diary-entry "diary-insert"
+(autoload 'insert-cyclic-diary-entry "diary-ins"
   "Insert a cyclic diary entry starting at the date indicated by point."
   t)
 
-(autoload 'insert-hebrew-diary-entry "diary-insert"
+(autoload 'insert-hebrew-diary-entry "diary-ins"
   "Insert a diary entry for the Hebrew date corresponding to the date
 indicated by point."
   t)
 
-(autoload 'insert-monthly-hebrew-diary-entry "diary-insert"
+(autoload 'insert-monthly-hebrew-diary-entry "diary-ins"
   "Insert a monthly diary entry for the day of the Hebrew month corresponding
 to the date indicated by point."
   t)
 
-(autoload 'insert-yearly-hebrew-diary-entry "diary-insert"
+(autoload 'insert-yearly-hebrew-diary-entry "diary-ins"
   "Insert an annual diary entry for the day of the Hebrew year corresponding
 to the date indicated by point."
   t)
 
-(autoload 'insert-islamic-diary-entry "diary-insert"
+(autoload 'insert-islamic-diary-entry "diary-ins"
   "Insert a diary entry for the Islamic date corresponding to the date
 indicated by point."
   t)
 
-(autoload 'insert-monthly-islamic-diary-entry "diary-insert"
+(autoload 'insert-monthly-islamic-diary-entry "diary-ins"
   "Insert a monthly diary entry for the day of the Islamic month corresponding
 to the date indicated by point."
   t)
 
-(autoload 'insert-yearly-islamic-diary-entry "diary-insert"
+(autoload 'insert-yearly-islamic-diary-entry "diary-ins"
   "Insert an annual diary entry for the day of the Islamic year corresponding
 to the date indicated by point."
   t)
@@ -53,7 +53,7 @@
 ;; The following files are part of the calendar/diary code:
 
-;;       diary.el, diary-insert.el     Diary functions
+;;       diary.el, diary-ins.el     Diary functions
 ;;       holidays.el                   Holiday functions
 ;;       cal-french.el                 French Revolutionary calendar